"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const events_1 = tslib_1.__importDefault(require("events"));
exports.eventEmitter = new events_1.default.EventEmitter();
// Emit event with better message error
function eventError(err, file) {
    if (err) {
        switch (err.code) {
            case 'EMFILE':
                exports.eventEmitter.emit('notice', file, `Too many open files, cannot ${err.syscall || 'access'}: `);
                break;
            case 'ENOENT':
                exports.eventEmitter.emit('notice', file, 'This file no longer exists: ');
                break;
            case 'EPERM':
                exports.eventEmitter.emit('warn', file, `Operation not permitted on this file (${err.syscall}): `);
                break;
            case 'ENOTEMPTY':
                // Work as intended
                break;
            default:
                if (err.message === '64bit files are not yet supported.') {
                    exports.eventEmitter.emit('warn', file, '64bit files are not yet supported.');
                }
                else {
                    exports.eventEmitter.emit('error', file, err);
                    // throw err
                }
            // break
        }
    }
}
exports.eventError = eventError;
exports.tree = {};
const debug = process.argv.includes('--debug');
if (debug) {
    exports.eventEmitter.on('debug', (file, message) => console.log('\x1b[38;2;128;0;128m Debug \x1b[39m' + message + file));
    exports.eventEmitter.on('info', (file, message) => console.log('\x1b[38;2;0;0;255m Info \x1b[39m' + message + file));
    exports.eventEmitter.on('notice', (file, message) => console.log('\x1b[38;2;0;255;255m Notice \x1b[39m' + message + file));
    exports.eventEmitter.on('warn', (file, message) => console.log('\x1b[38;2;255;255;0m Warn \x1b[39m' + message + file));
    exports.eventEmitter.on('error', (file, message) => console.log('\x1b[38;2;255;0;0m Error \x1b[39m' + message + file));
}
